<template>
    <el-dialog
        v-if="dialogVisible"
        title="详情列表"
        :visible.sync="dialogVisible"
        width="80%"
        :before-close="handleClose"
        v-loading="loading"
    >
        <ht-table
            @load="loadData"
            :data="data"
            :pageResult="pageResult"
            :selection="false"
            :show-export="false"
            :show-custom-column="false"
            :default-sorter="[
                {direction: 'DESC', property: 'HANDLING_SITUATION_'},
                {direction: 'DESC', property: 'CHECK_DATE_'},
            ]"
            :default-querys="defaultQuerys"
            ref="htTable"
            @row-dblclick="handleEdit"
        >
            <template>
                <ht-table-column
                    prop="roadName"
                    label="路段名称"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="diseaseCategory"
                    label="病害类别"
                    :show-overflow-tooltip="true"
                >
                    <template v-slot="{row}">
                        <div>{{ getDictName('bhlx', row.diseaseCategory) }}</div>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="type"
                    label="检查类别"
                    :show-overflow-tooltip="true"
                >
                    <template v-slot="{row}">
                        <div>{{ getDictName('xjlb', row.type) }}</div>
                    </template>
                </ht-table-column>

                <ht-table-column
                    prop="direction"
                    label="方向"
                    :filters="getDictData('qlfx')"
                    :show-overflow-tooltip="true"
                >
                    <template v-slot="{row}">
                        <div>{{ getDictName('qlfx', row.direction) }}</div>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="checkDate"
                    label="检查时间"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="positionName"
                    label="病害部位"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="description"
                    label="病害描述"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="handlingSituation"
                    label="处理情况"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                    <template v-slot="{row}">
                        <span v-if="row.handlingSituation == 0">未处理</span>
                        <span v-if="row.handlingSituation == 1">处理中</span>
                        <span v-if="row.handlingSituation == 2">已处理</span>
                        <span v-if="row.handlingSituation == 3">观察记录</span>
                    </template>
                </ht-table-column>
                <!-- <ht-table-column label="操作">
                    <template v-slot="{row}">
                    </template>
                </ht-table-column> -->
            </template>
        </ht-table>
        <span slot="footer" class="dialog-footer">
            <el-button @click="dialogVisible = false">取 消</el-button>
            <el-button type="primary" @click="dialogVisible = false">确 定</el-button>
        </span>

        <el-dialog
            v-if="outerVisible"
            title="病害详情"
            :visible.sync="outerVisible"
            width="50%"
            :before-close="handleClose"
            append-to-body
            v-loading="outerLoading"
        >
            <el-descriptions
                labelClassName="custom-label"
                contentClassName="custom-content"
            >
                <el-descriptions-item label="巡检类别">
                    {{ getDictName('xjlb', form.type) }}
                </el-descriptions-item>
                <el-descriptions-item label="方向">
                    {{ getDictName('qlfx', form.direction) }}
                </el-descriptions-item>
                <el-descriptions-item label="桩号或位置">
                    {{ form.startPeg }}
                </el-descriptions-item>
                <el-descriptions-item label="病害类别">
                    {{ getDictName('bhlx', form.diseaseCategory) }}
                </el-descriptions-item>
                <el-descriptions-item label="病害部位">
                    {{ form.positionName }}
                </el-descriptions-item>
                <el-descriptions-item label="路段">
                    {{ form.roadName }}
                </el-descriptions-item>
                <el-descriptions-item label="是否暂存">
                    {{ form.temporary ? '是' : '否' }}
                </el-descriptions-item>
                <el-descriptions-item label="病害高(mm)">
                    {{ form.paramHeight }}
                </el-descriptions-item>
                <el-descriptions-item label="病害长(mm)">
                    {{ form.paramLength }}
                </el-descriptions-item>
                <el-descriptions-item label="病害宽(mm)">
                    {{ form.paramWidth }}
                </el-descriptions-item>
                <el-descriptions-item label="检查时间">
                    {{ form.checkDate }}
                </el-descriptions-item>
                <el-descriptions-item label="病害描述">
                    {{ form.description }}
                </el-descriptions-item>
                <el-descriptions-item label="病害图片">
                    <el-image
                        v-for="i in fileList"
                        :key="i"
                        style="width: 100px; height: 100px"
                        :src="i"
                        :preview-src-list="fileList"
                    >
                    </el-image>
                </el-descriptions-item>
            </el-descriptions>
            <span slot="footer" class="dialog-footer">
                <el-button @click="outerVisible = false">取 消</el-button>
                <el-button type="primary" @click="outerVisible = false">确 定</el-button>
            </span>
        </el-dialog>
    </el-dialog>
</template>

<script>
export default {
    name: 'DialogVirusDetails',
    data() {
        return {
            dialogVisible: false,
            data: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            defaultQuerys: [],
            loading: false,
            outerVisible: false,
            outerLoading: false,
            form: {},
            fileList: [],
        }
    },
    methods: {
        handleEdit(data) {
            this.outerVisible = true
            this.outerLoading = true
            this.$http.get('${form}/disease/v1/get/' + data.id).then((res) => {
                let resp = res.data
                resp.accessories.forEach(i => {
                    this.fileList.push(i.url)
                })
                this.form = resp
                this.outerLoading = false
            })
        },
        open(data) {
            this.data = []
            this.dialogVisible = true
            this.defaultQuerys = [
                {
                    group: 'advance',
                    operation: 'EQUAL',
                    property: 'STRUCTURE_ID_',
                    relation: 'AND',
                    value: data.id,
                },
                {
                    group: 'advance',
                    operation: 'EQUAL',
                    property: 'DISEASE_CATEGORY_',
                    relation: 'AND',
                    value: data.diseaseCategory,
                },
            ]
            this.$nextTick(() => {
                this.$refs.htTable.load()
            })
        },
        handleClose(done) {
            done()
        },
        loadData(param, cb) {
            this.loading = true
            this.$http
                .post('${form}/disease/v1/getJson', param)
                .then(
                    (resp) => {
                        this.loading = false
                        this.data = resp.data.rows
                        this.pageResult = {
                            page: resp.data.page,
                            pageSize: resp.data.pageSize,
                            total: resp.data.total,
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-dialog .el-dialog__body,
/deep/ .el-dialog__footer {
    background-color: #0f304f;
}
/deep/ .el-descriptions__body {
    background-color: #103c5d;
    color: #fff;
    padding: 20px;
}
/deep/ .custom-label,
/deep/ .custom-content {
    font-size: 14px;
    line-height: 30px;
}
/deep/ .el-image {
    margin: 5px;
}
</style>
